scoretools.get_first_score_in_improper_parentage_of_component
=============================================================

.. autofunction:: abjad.tools.scoretools.get_first_score_in_improper_parentage_of_component
